@@ -647,7 +647,7 @@ ip6_routes_dialog_new (NMSettingIPConfig *s_ip6, gboolean automatic)
 
 	builder = gtk_builder_new ();
 
-	if (!gtk_builder_add_from_resource (builder, "/org/freedesktop/network-manager-applet/ce-ip6-routes.ui", &error)) {
+	if (!gtk_builder_add_from_resource (builder, "/org/gnome/nm_connection_editor/ce-ip6-routes.ui", &error)) {
 		g_warning ("Couldn't load builder resource: %s", error->message);
 		g_error_free (error);
 		return NULL;
