@@ -501,6 +501,12 @@ enable_toggled_cb (GtkToggleButton *button, EnableInfo *info)
 	ce_page_changed (info->page);
 }
 
+static void
+free_enable_info (gpointer data, GClosure *closure)
+{
+	g_free (data);
+}
+
 static void
 feature_setup (CEPageDcb *self, NMSettingDcb *s_dcb, const Feature *f)
 {
@@ -521,8 +527,7 @@ feature_setup (CEPageDcb *self, NMSettingDcb *s_dcb, const Feature *f)
 	info = g_malloc0 (sizeof (EnableInfo));
 	info->f = f;
 	info->page = parent;
-	g_signal_connect (widget, "toggled", G_CALLBACK (enable_toggled_cb), info);
-	g_object_weak_ref (G_OBJECT (widget), (GWeakNotify) g_free, info);
+	g_signal_connect_data (widget, "toggled", G_CALLBACK (enable_toggled_cb), info, free_enable_info, 0);
 
 	/* Advertise */
 	widget = get_widget (parent->builder, f->prefix, "_advertise_checkbutton");
@@ -617,7 +622,7 @@ ce_page_dcb_new (NMConnectionEditor *editor,
 	                                 connection,
 	                                 parent_window,
 	                                 client,
-	                                 "/org/freedesktop/network-manager-applet/ce-page-dcb.ui",
+	                                 "/org/gnome/nm_connection_editor/ce-page-dcb.ui",
 	                                 "DcbPage",
 	                                 _("DCB")));
 	if (!self) {
