@@ -431,9 +431,7 @@ get_selected_connection (CEPageMaster *self)
 	if (gtk_tree_model_get_iter (model, &iter, (GtkTreePath *) selected_rows->data))
 		gtk_tree_model_get (model, &iter, 0, &connection, -1);
 
-	/* free memory */
-	g_list_foreach (selected_rows, (GFunc) gtk_tree_path_free, NULL);
-	g_list_free (selected_rows);
+	g_list_free_full (selected_rows, (GDestroyNotify) gtk_tree_path_free);
 
 	return connection;
 }
