@@ -118,8 +118,8 @@ import_button_clicked_cb (GtkWidget *widget, CEPageProxy *self)
 	dialog = gtk_file_chooser_dialog_new (_("Select file to import"),
 	                                      GTK_WINDOW (toplevel),
 	                                      GTK_FILE_CHOOSER_ACTION_OPEN,
-	                                      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-	                                      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+	                                      _("_Cancel"), GTK_RESPONSE_CANCEL,
+	                                      _("_Open"), GTK_RESPONSE_ACCEPT,
 	                                      NULL);
 	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
@@ -210,7 +210,7 @@ ce_page_proxy_new (NMConnectionEditor *editor,
 	                                   connection,
 	                                   parent_window,
 	                                   client,
-	                                   "/org/freedesktop/network-manager-applet/ce-page-proxy.ui",
+	                                   "/org/gnome/nm_connection_editor/ce-page-proxy.ui",
 	                                   "ProxyPage",
 	                                   _("Proxy")));
 	if (!self) {
