@@ -647,7 +647,7 @@ ce_page_team_port_new (NMConnectionEditor *editor,
 	                                       connection,
 	                                       parent_window,
 	                                       client,
-	                                       "/org/freedesktop/network-manager-applet/ce-page-team-port.ui",
+	                                       "/org/gnome/nm_connection_editor/ce-page-team-port.ui",
 	                                       "TeamPortPage",
 	                                       /* Translators: a "Team Port" is a network
 	                                        * device that is part of a team.
